/* File: data_database_reader_test.h; Copyright and License: see below */

#ifndef DATA_DATABASE_READER_TEST_H
#define DATA_DATABASE_READER_TEST_H

/*!
 *  \file
 *  \brief MODULE TEST for data_database_writer, data_database_sql_builder, data_database and data_database_reader
 */

#include "test_suite.h"

test_suite_t data_database_reader_test_get_suite(void);

#endif  /* DATA_DATABASE_READER_TEST_H */


/*
 * Copyright 2017-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
